/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 2005-2006, Digium, Inc.
 *
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*! \file
 *
 * \brief Checks for active channels associated with an account
 * 
 * \author Justin Tunney <jtunney@gmail.com>
 */

#include "asterisk.h"

ASTERISK_FILE_VERSION(__FILE__, "$Revision: 1 $")

#include <stdio.h>
#include <string.h>

#include "asterisk/module.h"
#include "asterisk/channel.h"
#include "asterisk/pbx.h"
#include "asterisk/app.h"

static int accountactive_func_read_exec(struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len) 
{
	struct ast_channel *c = NULL;

	while ((c = ast_channel_walk_locked(c)) != NULL) {
		if (strcmp(data, c->cdr->accountcode) == 0) {
			ast_mutex_unlock(&c->lock);
			snprintf(buf, len, "1");
			return 0;
		}
		ast_mutex_unlock(&c->lock);
	}

	snprintf(buf, len, "0");
	return 0;
}

static struct ast_custom_function accountactive_function = {
	.name = "ACCOUNTACTIVE",
	.synopsis = "Checks for active channels using account",
	.syntax = "ACCOUNTACTIVE(<accountcode>)",
	.desc = ""
	"This function will go through the active channel list looking for\n"
	"channels where CDR(accountcode) has been set to the accountcode\n"
	"in question.  Returns 1 if any are found, 0 otherwise.\n"
	"\n"
	"This is useful if you are developing a calling card solution that\n"
	"can not have a single account in use more than once at a given\n"
	"moment.\n",
	.read = accountactive_func_read_exec,
};

static int unload_module(void)
{
	return ast_custom_function_unregister(&accountactive_function);
}

static int load_module(void)
{
	return ast_custom_function_register(&accountactive_function);
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Account usage detection function");
